*-------------------------------------------------------------------------------------*
* Configuration                                                                       *
* ------------------------------------------------------------------------------------*

*-------------------------------- specify your paths here! ---------------------------*
global dataDir 	"_SET_PATH_HERE_" // original data

global dir 		"_SET_PATH_HERE_" // folder with the project

global data		"${dir}/data"	
global posted	"${dir}/posted"
global graphs 	"${dir}/graphs"
global tables	"${dir}/tables"


* Select variables

use syear pid ple0008 using "${dataDir}\soeplongv31\pl.dta", clear // original data SOEP 2014
sort pid (syear)

merge 	1:1 pid syear using "${dataDir}\soeplongv31\pgen.dta", ///
		keepusing (pgcasmin) keep (1 3) nogen
sort pid (syear)

merge 	1:1 pid syear using "${dataDir}\soeplongv31\health.dta",  keep (1 3) nogen
sort pid (syear)

merge 	m:1 pid using "${dataDir}\soeplongv31\ppfad.dta", ///
		keepusing (sex gebjahr letztbef todjahr psample germborn loc1989 migback) ///
		keep (1 3) nogen
	

*-----------------------------------------------------------------------------*
*  Prepare  variables                                                         *
*-----------------------------------------------------------------------------*

* Self-rated health

// Recode so that higher values indicate better health
replace ple0008 = . if ple0008 < 0
recode  ple0008 (1=5) (2=4) (3=3) (4=2) (5=1), gen(srh)  

* Respondent died before end of observation period (2014)

gen died = 0											
replace died = 1 if todjahr > 1992

* Respondent left panel before end of observation period (2014)

gen left = letztbef < 2014 & died != 1

gen stayed = letztbef == 2014 & died != 1

* Gender

gen male = sex == 1

* Education
/*
The key grouping variable in this analysis is education (based on CASMIN). 
For every respondent, we take the highest level of education observed in the panel.
*/

bysort pid (syear): egen edu = max(pgcasmin)
replace edu = . if edu < 1
recode 	edu  				    ///
		(1 2 3   = 1 "1a-1c")	///
		(4 5 6 7 = 2 "2a-2c")	///
		(8 9     = 3 "3a-b")	///
		, gen(edu_cat)


* Age

gen age = syear - gebj


*-----------------------------------------------------------------------------*
*  Select sample                                                              *
*-----------------------------------------------------------------------------*

// Self-rated health was first measured in the wave 1992
drop if syear < 1992

** If from high-income sample
/*
SOEP includes a high income sample (presumably an access panel) .
This might bias the results, in particular because income is not included in the models.
*/
drop if psample == 7

// if sampled after 1992

bysort pid (syear): gen n = _n			
// nr is the number of observation for each respondent

bysort pid (syear): gen aux = syear if n == 1

bysort pid (syear): egen aux2 = max(aux)

drop if aux2> 1992

drop aux aux2

** If no information about year of birth
drop if gebj == -1 

** If not born in Germany
/* 
Two reasons for this exclusion:
1. Educational degree is often not comparable
2. Removes potential bias introduced by healthly migrant effects
*/
drop if germborn != 1 // Exclude those not born in Germany	 

** If from East Germany
/* 
Two reasons for this exclusion:
1. Educational degree is not comparable
2. Removes potential bias from vastly differing life conditions of birth cohorts
*/
drop if loc1989 != 2 // loc1989 is 2 if respondent was living in West Germany in 1949

drop if psample == 3 // Remove remaining respondents from East German sample 

** Cohort selection - If not aged 24-62 in the anchor year (wave 1992)
/*
This selection corresponds to a cohort range from 1930 (age 62 at wave 1992) 
to 1968 (age 24 at wave 1992). 
*/
gen aux = inrange(age, 23, 62) & syear == 1992 
// aux is 1 if a respondent was aged between 24 and 62 in 1992
bysort pid (syear): egen aux2 = max(aux)       
// age in 1992 defined as a time-constant variable

drop if aux2 == 0
                              
drop aux aux2

** If no information about education
drop if edu == . 

                                          
*-----------------------------------------------------------------------------*
* Generate more variables                                                     *
*-----------------------------------------------------------------------------*

bysort pid (syear): gen N = _N	
// N is the total number of observations for each respondent

* Center age at grand median

sum age, d
gen age_c = age - r(p50)

* Higher polynomials of age

gen age_2   = age*age

sum age_2, d
gen age_2_c = age_2 - r(p50)

gen age_3   = age*age*age

sum age_3, d
gen age_3_c = age_3 - r(p50)

gen age_4   = age*age*age*age

sum age_4, d
gen age_4_c = age_4 - r(p50)

* Define groups of cohorts

egen cohort = cut(gebjahr), at(1930(10)1970)

tabulate cohort, gen (cohort_)

* Center cohort at the median age at entry (i.e., in 1992)

// Increasing values of cohort indicate more recent cohorts
gen coh = age if syear == 1992
bysort pid (syear): egen coh_max = max(coh)	// cohort is time-constant
gen aux = coh - 40 // 40 is median age in 1992 
bysort pid (syear): egen coh_c = max(aux)	// cohort is time-constant
drop aux

* Generate categorical education variables for descriptives and multivariate models

/* In the German context, education years alone is an insufficient measure.
Educational analyses in Germany must take into account educational degrees 
and how they structure life courses.
*/

* Education for descriptive statistics and cohort-specific models
// Note that not all methods applied below can use factor variables.

gen edu_low =  inlist(edu_cat,1)
gen edu_mid  = inlist(edu_cat,2)
gen edu_high = inlist(edu_cat,3)


*-----------------------------------------------------------------------------*
*  Save to folder "posted"                                                    *
*-----------------------------------------------------------------------------*

save "${dir}/02_posted/data", replace


